package
Version:
v0.0.0-...-3735932
Opens a new window with list of versions in this module.
Published: Feb 7, 2024
License: AGPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BaseModel struct {
ID uint `gorm:"primarykey" json:"id"`
CreatedAt Time ` json:"createdAt"`
UpdatedAt Time ` json:"updatedAt"`
DeletedAt gorm.DeletedAt `gorm:"index" json:"deletedAt"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.